@@ -38,6 +38,8 @@
 
 #include <config.h>
 
+#include <sys/types.h>
+
 #include <stdio.h>
 #include <ctype.h>
 #ifdef HAVE_STRING_H
@@ -47,7 +49,7 @@
 # include <strings.h>
 #endif /* HAVE_STRINGS_H */
 
-#include <compat.h>
+#include "missing.h"
 #include "emul/fnmatch.h"
 #include "emul/charclass.h"
 
@@ -78,17 +80,17 @@ fnmatch(pattern, string, flags)
 		switch (c = *pattern++) {
 		case EOS:
 			if (ISSET(flags, FNM_LEADING_DIR) && *string == '/')
-				return (0);
-			return (*string == EOS ? 0 : FNM_NOMATCH);
+				return 0;
+			return *string == EOS ? 0 : FNM_NOMATCH;
 		case '?':
 			if (*string == EOS)
-				return (FNM_NOMATCH);
+				return FNM_NOMATCH;
 			if (*string == '/' && ISSET(flags, FNM_PATHNAME))
-				return (FNM_NOMATCH);
+				return FNM_NOMATCH;
 			if (*string == '.' && ISSET(flags, FNM_PERIOD) &&
 			    (string == stringstart ||
 			    (ISSET(flags, FNM_PATHNAME) && *(string - 1) == '/')))
-				return (FNM_NOMATCH);
+				return FNM_NOMATCH;
 			++string;
 			break;
 		case '*':
@@ -100,40 +102,40 @@ fnmatch(pattern, string, flags)
 			if (*string == '.' && ISSET(flags, FNM_PERIOD) &&
 			    (string == stringstart ||
 			    (ISSET(flags, FNM_PATHNAME) && *(string - 1) == '/')))
-				return (FNM_NOMATCH);
+				return FNM_NOMATCH;
 
 			/* Optimize for pattern with * at end or before /. */
 			if (c == EOS) {
 				if (ISSET(flags, FNM_PATHNAME))
-					return (ISSET(flags, FNM_LEADING_DIR) ||
+					return ISSET(flags, FNM_LEADING_DIR) ||
 					    strchr(string, '/') == NULL ?
-					    0 : FNM_NOMATCH);
+					    0 : FNM_NOMATCH;
 				else
-					return (0);
+					return 0;
 			} else if (c == '/' && ISSET(flags, FNM_PATHNAME)) {
 				if ((string = strchr(string, '/')) == NULL)
-					return (FNM_NOMATCH);
+					return FNM_NOMATCH;
 				break;
 			}
 
 			/* General case, use recursion. */
 			while ((test = *string) != EOS) {
 				if (!fnmatch(pattern, string, flags & ~FNM_PERIOD))
-					return (0);
+					return 0;
 				if (test == '/' && ISSET(flags, FNM_PATHNAME))
 					break;
 				++string;
 			}
-			return (FNM_NOMATCH);
+			return FNM_NOMATCH;
 		case '[':
 			if (*string == EOS)
-				return (FNM_NOMATCH);
+				return FNM_NOMATCH;
 			if (*string == '/' && ISSET(flags, FNM_PATHNAME))
-				return (FNM_NOMATCH);
+				return FNM_NOMATCH;
 			if (*string == '.' && ISSET(flags, FNM_PERIOD) &&
 			    (string == stringstart ||
 			    (ISSET(flags, FNM_PATHNAME) && *(string - 1) == '/')))
-				return (FNM_NOMATCH);
+				return FNM_NOMATCH;
 
 			switch (rangematch(pattern, *string, flags, &newp)) {
 			case RANGE_ERROR:
@@ -143,7 +145,7 @@ fnmatch(pattern, string, flags)
 				pattern = newp;
 				break;
 			case RANGE_NOMATCH:
-				return (FNM_NOMATCH);
+				return FNM_NOMATCH;
 			}
 			++string;
 			break;
@@ -160,7 +162,7 @@ fnmatch(pattern, string, flags)
 			if (c != *string && !(ISSET(flags, FNM_CASEFOLD) &&
 				 (tolower((unsigned char)c) ==
 				 tolower((unsigned char)*string))))
-				return (FNM_NOMATCH);
+				return FNM_NOMATCH;
 			++string;
 			break;
 		}
@@ -216,9 +218,9 @@ rangematch(pattern, test, flags, newp)
 		if (c == '\\' && !ISSET(flags, FNM_NOESCAPE))
 			c = *pattern++;
 		if (c == EOS)
-			return (RANGE_ERROR);
+			return RANGE_ERROR;
 		if (c == '/' && ISSET(flags, FNM_PATHNAME))
-			return (RANGE_NOMATCH);
+			return RANGE_NOMATCH;
 		if (ISSET(flags, FNM_CASEFOLD))
 			c = tolower((unsigned char)c);
 		if (*pattern == '-'
@@ -227,7 +229,7 @@ rangematch(pattern, test, flags, newp)
 			if (c2 == '\\' && !ISSET(flags, FNM_NOESCAPE))
 				c2 = *pattern++;
 			if (c2 == EOS)
-				return (RANGE_ERROR);
+				return RANGE_ERROR;
 			if (ISSET(flags, FNM_CASEFOLD))
 				c2 = tolower((unsigned char)c2);
 			if (c <= test && test <= c2)
@@ -237,7 +239,7 @@ rangematch(pattern, test, flags, newp)
 	} while ((c = *pattern++) != ']');
 
 	*newp = (char *)pattern;
-	return (ok == negate ? RANGE_NOMATCH : RANGE_MATCH);
+	return ok == negate ? RANGE_NOMATCH : RANGE_MATCH;
 }
 
 static int
@@ -258,7 +260,7 @@ classmatch(pattern, test, foldcase, ep)
 
 	if ((colon = strchr(pattern, ':')) == NULL || colon[1] != ']') {
 		*ep = pattern - 2;
-		return(RANGE_ERROR);
+		return RANGE_ERROR;
 	}
 	*ep = colon + 2;
 	len = (size_t)(colon - pattern);
@@ -277,5 +279,5 @@ classmatch(pattern, test, foldcase, ep)
 		*ep = colon + strlen(colon);
 		rval = RANGE_ERROR;
 	}
-	return(rval);
+	return rval;
 }
