@@ -71,7 +71,7 @@
 # endif
 #endif
 
-#include <compat.h>
+#include "missing.h"
 
 #define	ISDOT(dp) \
 	(dp->d_name[0] == '.' && (dp->d_name[1] == '\0' || \
@@ -104,12 +104,12 @@ getcwd(pt, size)
 		ptsize = 0;
 		if (!size) {
 			errno = EINVAL;
-			return (NULL);
+			return NULL;
 		}
 		ept = pt + size;
 	} else {
 		if ((pt = malloc(ptsize = 1024 - 4)) == NULL)
-			return (NULL);
+			return NULL;
 		ept = pt + ptsize;
 	}
 	bpt = ept - 1;
@@ -154,7 +154,7 @@ getcwd(pt, size)
 			 */
 			bcopy(bpt, pt, ept - bpt);
 			free(up);
-			return (pt);
+			return pt;
 		}
 
 		/*
@@ -262,5 +262,5 @@ err:
 		free(up);
 	if (dir)
 		(void)closedir(dir);
-	return (NULL);
+	return NULL;
 }
